@@ -14,7 +14,7 @@ var githubServiceDef = ServiceDefinition{
 	provider:                        "github",
 	pullRequestURLIntoDefaultBranch: "/compare/{{.From}}?expand=1",
 	pullRequestURLIntoTargetBranch:  "/compare/{{.To}}...{{.From}}?expand=1",
-	commitURL:                       "/commit/{{.CommitSha}}",
+	commitURL:                       "/commit/{{.CommitHash}}",
 	regexStrings:                    defaultUrlRegexStrings,
 	repoURLTemplate:                 defaultRepoURLTemplate,
 }
@@ -23,7 +23,7 @@ var bitbucketServiceDef = ServiceDefinition{
 	provider:                        "bitbucket",
 	pullRequestURLIntoDefaultBranch: "/pull-requests/new?source={{.From}}&t=1",
 	pullRequestURLIntoTargetBranch:  "/pull-requests/new?source={{.From}}&dest={{.To}}&t=1",
-	commitURL:                       "/commits/{{.CommitSha}}",
+	commitURL:                       "/commits/{{.CommitHash}}",
 	regexStrings: []string{
 		`^(?:https?|ssh)://.*/(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
 		`^.*@.*:(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
@@ -35,7 +35,7 @@ var gitLabServiceDef = ServiceDefinition{
 	provider:                        "gitlab",
 	pullRequestURLIntoDefaultBranch: "/-/merge_requests/new?merge_request[source_branch]={{.From}}",
 	pullRequestURLIntoTargetBranch:  "/-/merge_requests/new?merge_request[source_branch]={{.From}}&merge_request[target_branch]={{.To}}",
-	commitURL:                       "/-/commit/{{.CommitSha}}",
+	commitURL:                       "/-/commit/{{.CommitHash}}",
 	regexStrings:                    defaultUrlRegexStrings,
 	repoURLTemplate:                 defaultRepoURLTemplate,
 }
@@ -44,7 +44,7 @@ var azdoServiceDef = ServiceDefinition{
 	provider:                        "azuredevops",
 	pullRequestURLIntoDefaultBranch: "/pullrequestcreate?sourceRef={{.From}}",
 	pullRequestURLIntoTargetBranch:  "/pullrequestcreate?sourceRef={{.From}}&targetRef={{.To}}",
-	commitURL:                       "/commit/{{.CommitSha}}",
+	commitURL:                       "/commit/{{.CommitHash}}",
 	regexStrings: []string{
 		`^git@ssh.dev.azure.com.*/(?P<org>.*)/(?P<project>.*)/(?P<repo>.*?)(?:\.git)?$`,
 		`^https://.*@dev.azure.com/(?P<org>.*?)/(?P<project>.*?)/_git/(?P<repo>.*?)(?:\.git)?$`,
@@ -56,7 +56,7 @@ var bitbucketServerServiceDef = ServiceDefinition{
 	provider:                        "bitbucketServer",
 	pullRequestURLIntoDefaultBranch: "/pull-requests?create&sourceBranch={{.From}}",
 	pullRequestURLIntoTargetBranch:  "/pull-requests?create&targetBranch={{.To}}&sourceBranch={{.From}}",
-	commitURL:                       "/commits/{{.CommitSha}}",
+	commitURL:                       "/commits/{{.CommitHash}}",
 	regexStrings: []string{
 		`^ssh://git@.*/(?P<project>.*)/(?P<repo>.*?)(?:\.git)?$`,
 		`^https://.*/scm/(?P<project>.*)/(?P<repo>.*?)(?:\.git)?$`,
@@ -68,7 +68,7 @@ var giteaServiceDef = ServiceDefinition{
 	provider:                        "gitea",
 	pullRequestURLIntoDefaultBranch: "/compare/{{.From}}",
 	pullRequestURLIntoTargetBranch:  "/compare/{{.To}}...{{.From}}",
-	commitURL:                       "/commit/{{.CommitSha}}",
+	commitURL:                       "/commit/{{.CommitHash}}",
 	regexStrings:                    defaultUrlRegexStrings,
 	repoURLTemplate:                 defaultRepoURLTemplate,
 }
