@@ -1,6 +1,8 @@
 package context
 
 import (
+	"fmt"
+
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
@@ -28,7 +30,7 @@ func NewCommitFilesContext(c *ContextCommon) *CommitFilesContext {
 	viewModel := filetree.NewCommitFileTreeViewModel(
 		func() []*models.CommitFile { return c.Model().CommitFiles },
 		c.Log,
-		c.UserConfig.Gui.ShowFileTree,
+		c.UserConfig().Gui.ShowFileTree,
 	)
 
 	getDisplayStrings := func(_ int, _ int) [][]string {
@@ -36,7 +38,7 @@ func NewCommitFilesContext(c *ContextCommon) *CommitFilesContext {
 			return [][]string{{style.FgRed.Sprint("(none)")}}
 		}
 
-		showFileIcons := icons.IsIconEnabled() && c.UserConfig.Gui.ShowFileIcons
+		showFileIcons := icons.IsIconEnabled() && c.UserConfig().Gui.ShowFileIcons
 		lines := presentation.RenderCommitFileTree(viewModel, c.Git().Patch.PatchBuilder, showFileIcons)
 		return lo.Map(lines, func(line string, _ int) []string {
 			return []string{line}
@@ -75,6 +77,25 @@ func (self *CommitFilesContext) GetDiffTerminals() []string {
 	return []string{self.GetRef().RefName()}
 }
 
+func (self *CommitFilesContext) GetFromAndToForDiff() (string, string) {
+	if refs := self.GetRefRange(); refs != nil {
+		return refs.From.ParentRefName(), refs.To.RefName()
+	}
+	ref := self.GetRef()
+	return ref.ParentRefName(), ref.RefName()
+}
+
 func (self *CommitFilesContext) ModelSearchResults(searchStr string, caseSensitive bool) []gocui.SearchPosition {
 	return nil
 }
+
+func (self *CommitFilesContext) ReInit(ref types.Ref, refRange *types.RefRange) {
+	self.SetRef(ref)
+	self.SetRefRange(refRange)
+	if refRange != nil {
+		self.SetTitleRef(fmt.Sprintf("%s-%s", refRange.From.ShortRefName(), refRange.To.ShortRefName()))
+	} else {
+		self.SetTitleRef(ref.Description())
+	}
+	self.GetView().Title = self.Title()
+}
