@@ -53,7 +53,8 @@ func NewPatchExplorerContext(
 		func(selectedLineIdx int) error {
 			ctx.GetMutex().Lock()
 			defer ctx.GetMutex().Unlock()
-			return ctx.NavigateTo(ctx.c.IsCurrentContext(ctx), selectedLineIdx)
+			ctx.NavigateTo(ctx.c.Context().IsCurrent(ctx), selectedLineIdx)
+			return nil
 		}),
 	)
 
@@ -78,28 +79,22 @@ func (self *PatchExplorerContext) GetIncludedLineIndices() []int {
 	return self.getIncludedLineIndices()
 }
 
-func (self *PatchExplorerContext) RenderAndFocus(isFocused bool) error {
+func (self *PatchExplorerContext) RenderAndFocus(isFocused bool) {
 	self.setContent(isFocused)
 
 	self.FocusSelection()
 	self.c.Render()
-
-	return nil
 }
 
-func (self *PatchExplorerContext) Render(isFocused bool) error {
+func (self *PatchExplorerContext) Render(isFocused bool) {
 	self.setContent(isFocused)
 
 	self.c.Render()
-
-	return nil
 }
 
-func (self *PatchExplorerContext) Focus() error {
+func (self *PatchExplorerContext) Focus() {
 	self.FocusSelection()
 	self.c.Render()
-
-	return nil
 }
 
 func (self *PatchExplorerContext) setContent(isFocused bool) {
@@ -116,7 +111,7 @@ func (self *PatchExplorerContext) FocusSelection() {
 
 	newOriginY := state.CalculateOrigin(origin, bufferHeight, numLines)
 
-	_ = view.SetOriginY(newOriginY)
+	view.SetOriginY(newOriginY)
 
 	startIdx, endIdx := state.SelectedRange()
 	// As far as the view is concerned, we are always selecting a range
@@ -132,11 +127,11 @@ func (self *PatchExplorerContext) GetContentToRender(isFocused bool) string {
 	return self.GetState().RenderForLineIndices(isFocused, self.GetIncludedLineIndices())
 }
 
-func (self *PatchExplorerContext) NavigateTo(isFocused bool, selectedLineIdx int) error {
+func (self *PatchExplorerContext) NavigateTo(isFocused bool, selectedLineIdx int) {
 	self.GetState().SetLineSelectMode()
 	self.GetState().SelectLine(selectedLineIdx)
 
-	return self.RenderAndFocus(isFocused)
+	self.RenderAndFocus(isFocused)
 }
 
 func (self *PatchExplorerContext) GetMutex() *deadlock.Mutex {
