@@ -26,7 +26,7 @@ func NewRemotesContext(c *ContextCommon) *RemotesContext {
 
 	getDisplayStrings := func(_ int, _ int) [][]string {
 		return presentation.GetRemoteListDisplayStrings(
-			viewModel.GetItems(), c.Modes().Diffing.Ref, c.State().GetItemOperation, c.Tr)
+			viewModel.GetItems(), c.Modes().Diffing.Ref, c.State().GetItemOperation, c.Tr, c.UserConfig())
 	}
 
 	return &RemotesContext{
