@@ -44,17 +44,29 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 
 	cmdOptions := git_commands.CheckoutOptions{Force: false, EnvVars: options.EnvVars}
 
-	onSuccess := func() {
+	refresh := func() {
 		self.c.Contexts().Branches.SetSelection(0)
 		self.c.Contexts().ReflogCommits.SetSelection(0)
 		self.c.Contexts().LocalCommits.SetSelection(0)
 		// loading a heap of commits is slow so we limit them whenever doing a reset
 		self.c.Contexts().LocalCommits.SetLimitCommits(true)
+
+		_ = self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
 	}
 
-	refreshOptions := types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true}
+	localBranch, found := lo.Find(self.c.Model().Branches, func(branch *models.Branch) bool {
+		return branch.Name == ref
+	})
 
-	f := func(gocui.Task) error {
+	withCheckoutStatus := func(f func(gocui.Task) error) error {
+		if found {
+			return self.c.WithInlineStatus(localBranch, types.ItemOperationCheckingOut, context.LOCAL_BRANCHES_CONTEXT_KEY, f)
+		} else {
+			return self.c.WithWaitingStatus(waitingStatus, f)
+		}
+	}
+
+	return withCheckoutStatus(func(gocui.Task) error {
 		if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
 			// note, this will only work for english-language git commands. If we force git to use english, and the error isn't this one, then the user will receive an english command they may not understand. I'm not sure what the best solution to this is. Running the command once in english and a second time in the native language is one option
 
@@ -62,46 +74,41 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 				return options.OnRefNotFound(ref)
 			}
 
-			if strings.Contains(err.Error(), "Please commit your changes or stash them before you switch branch") {
+			if IsSwitchBranchUncommitedChangesError(err) {
 				// offer to autostash changes
-				return self.c.Confirm(types.ConfirmOpts{
-					Title:  self.c.Tr.AutoStashTitle,
-					Prompt: self.c.Tr.AutoStashPrompt,
-					HandleConfirm: func() error {
-						if err := self.c.Git().Stash.Push(self.c.Tr.StashPrefix + ref); err != nil {
-							return err
-						}
-						if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
-							return err
-						}
-
-						onSuccess()
-						if err := self.c.Git().Stash.Pop(0); err != nil {
-							if err := self.c.Refresh(refreshOptions); err != nil {
+				self.c.OnUIThread(func() error {
+					// (Before showing the prompt, render again to remove the inline status)
+					self.c.Contexts().Branches.HandleRender()
+					self.c.Confirm(types.ConfirmOpts{
+						Title:  self.c.Tr.AutoStashTitle,
+						Prompt: self.c.Tr.AutoStashPrompt,
+						HandleConfirm: func() error {
+							return withCheckoutStatus(func(gocui.Task) error {
+								if err := self.c.Git().Stash.Push(self.c.Tr.StashPrefix + ref); err != nil {
+									return err
+								}
+								if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
+									return err
+								}
+								err := self.c.Git().Stash.Pop(0)
+								// Branch switch successful so re-render the UI even if the pop operation failed (e.g. conflict).
+								refresh()
 								return err
-							}
-							return err
-						}
-						return self.c.Refresh(refreshOptions)
-					},
+							})
+						},
+					})
+
+					return nil
 				})
+				return nil
 			}
 
 			return err
 		}
-		onSuccess()
 
-		return self.c.Refresh(refreshOptions)
-	}
-
-	localBranch, found := lo.Find(self.c.Model().Branches, func(branch *models.Branch) bool {
-		return branch.Name == ref
+		refresh()
+		return nil
 	})
-	if found {
-		return self.c.WithInlineStatus(localBranch, types.ItemOperationCheckingOut, context.LOCAL_BRANCHES_CONTEXT_KEY, f)
-	} else {
-		return self.c.WithWaitingStatus(waitingStatus, f)
-	}
 }
 
 // Shows a prompt to choose between creating a new branch or checking out a detached head
@@ -109,10 +116,8 @@ func (self *RefsHelper) CheckoutRemoteBranch(fullBranchName string, localBranchN
 	checkout := func(branchName string) error {
 		// Switch to the branches context _before_ starting to check out the
 		// branch, so that we see the inline status
-		if self.c.CurrentContext() != self.c.Contexts().Branches {
-			if err := self.c.PushContext(self.c.Contexts().Branches); err != nil {
-				return err
-			}
+		if self.c.Context().Current() != self.c.Contexts().Branches {
+			self.c.Context().Push(self.c.Contexts().Branches)
 		}
 		return self.CheckoutRef(branchName, types.CheckoutRefOptions{})
 	}
@@ -275,10 +280,21 @@ func (self *RefsHelper) NewBranch(from string, fromFormattedName string, suggest
 	)
 
 	if suggestedBranchName == "" {
-		suggestedBranchName = self.c.UserConfig.Git.BranchPrefix
+		suggestedBranchName = self.c.UserConfig().Git.BranchPrefix
 	}
 
-	return self.c.Prompt(types.PromptOpts{
+	refresh := func() error {
+		if self.c.Context().Current() != self.c.Contexts().Branches {
+			self.c.Context().Push(self.c.Contexts().Branches)
+		}
+
+		self.c.Contexts().LocalCommits.SetSelection(0)
+		self.c.Contexts().Branches.SetSelection(0)
+
+		return self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
+	}
+
+	self.c.Prompt(types.PromptOpts{
 		Title:          message,
 		InitialContent: suggestedBranchName,
 		HandleConfirm: func(response string) error {
@@ -289,21 +305,40 @@ func (self *RefsHelper) NewBranch(from string, fromFormattedName string, suggest
 				newBranchFunc = self.c.Git().Branch.NewWithoutTracking
 			}
 			if err := newBranchFunc(newBranchName, from); err != nil {
+				if IsSwitchBranchUncommitedChangesError(err) {
+					// offer to autostash changes
+					self.c.Confirm(types.ConfirmOpts{
+						Title:  self.c.Tr.AutoStashTitle,
+						Prompt: self.c.Tr.AutoStashPrompt,
+						HandleConfirm: func() error {
+							if err := self.c.Git().Stash.Push(self.c.Tr.StashPrefix + newBranchName); err != nil {
+								return err
+							}
+							if err := newBranchFunc(newBranchName, from); err != nil {
+								return err
+							}
+							popErr := self.c.Git().Stash.Pop(0)
+							// Branch switch successful so re-render the UI even if the pop operation failed (e.g. conflict).
+							refreshError := refresh()
+							if popErr != nil {
+								// An error from pop is the more important one to report to the user
+								return popErr
+							}
+							return refreshError
+						},
+					})
+
+					return nil
+				}
+
 				return err
 			}
 
-			if self.c.CurrentContext() != self.c.Contexts().Branches {
-				if err := self.c.PushContext(self.c.Contexts().Branches); err != nil {
-					return err
-				}
-			}
-
-			self.c.Contexts().LocalCommits.SetSelection(0)
-			self.c.Contexts().Branches.SetSelection(0)
-
-			return self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
+			return refresh()
 		},
 	})
+
+	return nil
 }
 
 // SanitizedBranchName will remove all spaces in favor of a dash "-" to meet
@@ -329,3 +364,7 @@ func (self *RefsHelper) ParseRemoteBranchName(fullBranchName string) (string, st
 
 	return remoteName, branchName, true
 }
+
+func IsSwitchBranchUncommitedChangesError(err error) bool {
+	return strings.Contains(err.Error(), "Please commit your changes or stash them before you switch branch")
+}
