@@ -1,6 +1,8 @@
 package filetree
 
 import (
+	"path"
+
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/samber/lo"
@@ -39,6 +41,10 @@ func (self *Node[T]) IsFile() bool {
 	return self.File != nil
 }
 
+func (self *Node[T]) GetFile() *T {
+	return self.File
+}
+
 func (self *Node[T]) GetPath() string {
 	return self.Path
 }
@@ -300,3 +306,7 @@ func (self *Node[T]) ID() string {
 func (self *Node[T]) Description() string {
 	return self.GetPath()
 }
+
+func (self *Node[T]) Name() string {
+	return path.Base(self.Path)
+}
