@@ -5,6 +5,9 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"path/filepath"
+	"reflect"
+	"regexp"
 	"sort"
 	"strings"
 	"sync"
@@ -35,6 +38,7 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/gui/status"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
+	"github.com/jesseduffield/lazygit/pkg/i18n"
 	"github.com/jesseduffield/lazygit/pkg/integration/components"
 	integrationTypes "github.com/jesseduffield/lazygit/pkg/integration/types"
 	"github.com/jesseduffield/lazygit/pkg/tasks"
@@ -137,6 +141,8 @@ type Gui struct {
 	c       *helpers.HelperCommon
 	helpers *helpers.Helpers
 
+	previousLanguageConfig string
+
 	integrationTest integrationTypes.IntegrationTest
 
 	afterLayoutFuncs chan func() error
@@ -307,6 +313,16 @@ func (gui *Gui) onNewRepo(startArgs appTypes.StartArgs, contextKey types.Context
 		return err
 	}
 
+	err = gui.Config.ReloadUserConfigForRepo(gui.getPerRepoConfigFiles())
+	if err != nil {
+		return err
+	}
+
+	err = gui.onUserConfigLoaded()
+	if err != nil {
+		return err
+	}
+
 	contextToPush := gui.resetState(startArgs)
 
 	gui.resetHelpersAndControllers()
@@ -317,8 +333,50 @@ func (gui *Gui) onNewRepo(startArgs appTypes.StartArgs, contextKey types.Context
 
 	gui.g.SetFocusHandler(func(Focused bool) error {
 		if Focused {
+			oldConfig := gui.Config.GetUserConfig()
+			reloadErr, didChange := gui.Config.ReloadChangedUserConfigFiles()
+			if didChange && reloadErr == nil {
+				gui.c.Log.Info("User config changed - reloading")
+				reloadErr = gui.onUserConfigLoaded()
+				if err := gui.resetKeybindings(); err != nil {
+					return err
+				}
+
+				if err := gui.checkForChangedConfigsThatDontAutoReload(oldConfig, gui.Config.GetUserConfig()); err != nil {
+					return err
+				}
+			}
+
 			gui.c.Log.Info("Receiving focus - refreshing")
-			return gui.helpers.Refresh.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+			refreshErr := gui.helpers.Refresh.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+			if reloadErr != nil {
+				// An error from reloading the config is the more important one
+				// to report to the user
+				return reloadErr
+			}
+			return refreshErr
+		}
+
+		return nil
+	})
+
+	gui.g.SetOpenHyperlinkFunc(func(url string) error {
+		if strings.HasPrefix(url, "lazygit-edit:") {
+			re := regexp.MustCompile(`^lazygit-edit://(.+?)(?::(\d+))?$`)
+			matches := re.FindStringSubmatch(url)
+			if matches == nil {
+				return fmt.Errorf(gui.Tr.InvalidLazygitEditURL, url)
+			}
+			filepath := matches[1]
+			if matches[2] != "" {
+				lineNumber := utils.MustConvertToInt(matches[2])
+				return gui.helpers.Files.EditFileAtLine(filepath, lineNumber)
+			}
+			return gui.helpers.Files.EditFiles([]string{filepath})
+		}
+
+		if err := gui.os.OpenLink(url); err != nil {
+			return fmt.Errorf(gui.Tr.FailedToOpenURL, url, err)
 		}
 
 		return nil
@@ -335,22 +393,128 @@ func (gui *Gui) onNewRepo(startArgs appTypes.StartArgs, contextKey types.Context
 		}
 	}
 
-	if err := gui.c.PushContext(contextToPush); err != nil {
-		return err
-	}
+	gui.c.Context().Push(contextToPush)
 
 	return nil
 }
 
-// resetState determines if we pull the repo state from our repo state map or
-// just re-initialize it. For now we're only re-using state when we're going
-// in and out of submodules, for the sake of having the cursor back on the submodule
-// when we return.
-//
-// I tried out always reverting to the repo's original state but found that in fact
-// it gets a bit confusing to land back in the status panel when visiting a repo
-// you've already switched from. There's no doubt some easy way to make the UX
-// optimal for all cases but I'm too lazy to think about what that is right now
+func (gui *Gui) getPerRepoConfigFiles() []*config.ConfigFile {
+	repoConfigFiles := []*config.ConfigFile{
+		// TODO: add filepath.Join(gui.git.RepoPaths.RepoPath(), ".lazygit.yml"),
+		// with trust prompt
+		{
+			Path:   filepath.Join(gui.git.RepoPaths.RepoGitDirPath(), "lazygit.yml"),
+			Policy: config.ConfigFilePolicySkipIfMissing,
+		},
+	}
+
+	prevDir := gui.c.Git().RepoPaths.RepoPath()
+	dir := filepath.Dir(prevDir)
+	for dir != prevDir {
+		repoConfigFiles = utils.Prepend(repoConfigFiles, &config.ConfigFile{
+			Path:   filepath.Join(dir, ".lazygit.yml"),
+			Policy: config.ConfigFilePolicySkipIfMissing,
+		})
+		prevDir = dir
+		dir = filepath.Dir(dir)
+	}
+	return repoConfigFiles
+}
+
+func (gui *Gui) onUserConfigLoaded() error {
+	userConfig := gui.Config.GetUserConfig()
+	gui.Common.SetUserConfig(userConfig)
+
+	gui.setColorScheme()
+	gui.configureViewProperties()
+
+	gui.g.SearchEscapeKey = keybindings.GetKey(userConfig.Keybinding.Universal.Return)
+	gui.g.NextSearchMatchKey = keybindings.GetKey(userConfig.Keybinding.Universal.NextMatch)
+	gui.g.PrevSearchMatchKey = keybindings.GetKey(userConfig.Keybinding.Universal.PrevMatch)
+
+	gui.g.ShowListFooter = userConfig.Gui.ShowListFooter
+
+	gui.g.Mouse = userConfig.Gui.MouseEvents
+
+	if gui.previousLanguageConfig != userConfig.Gui.Language {
+		tr, err := i18n.NewTranslationSetFromConfig(gui.Log, userConfig.Gui.Language)
+		if err != nil {
+			return err
+		}
+		gui.c.Tr = tr
+		gui.previousLanguageConfig = userConfig.Gui.Language
+	}
+
+	// originally we could only hide the command log permanently via the config
+	// but now we do it via state. So we need to still support the config for the
+	// sake of backwards compatibility. We're making use of short circuiting here
+	gui.ShowExtrasWindow = userConfig.Gui.ShowCommandLog && !gui.c.GetAppState().HideCommandLog
+
+	authors.SetCustomAuthors(userConfig.Gui.AuthorColors)
+	if userConfig.Gui.NerdFontsVersion != "" {
+		icons.SetNerdFontsVersion(userConfig.Gui.NerdFontsVersion)
+	} else if userConfig.Gui.ShowIcons {
+		icons.SetNerdFontsVersion("2")
+	}
+	presentation.SetCustomBranches(userConfig.Gui.BranchColors)
+
+	return nil
+}
+
+func (gui *Gui) checkForChangedConfigsThatDontAutoReload(oldConfig *config.UserConfig, newConfig *config.UserConfig) error {
+	configsThatDontAutoReload := []string{
+		"Git.AutoFetch",
+		"Git.AutoRefresh",
+		"Refresher.RefreshInterval",
+		"Refresher.FetchInterval",
+		"Update.Method",
+		"Update.Days",
+	}
+
+	changedConfigs := []string{}
+	for _, config := range configsThatDontAutoReload {
+		old := reflect.ValueOf(oldConfig).Elem()
+		new := reflect.ValueOf(newConfig).Elem()
+		fieldNames := strings.Split(config, ".")
+		userFacingPath := make([]string, 0, len(fieldNames))
+		// navigate to the leaves in old and new config
+		for _, fieldName := range fieldNames {
+			f, _ := old.Type().FieldByName(fieldName)
+			userFacingName := f.Tag.Get("yaml")
+			if userFacingName == "" {
+				userFacingName = fieldName
+			}
+			userFacingPath = append(userFacingPath, userFacingName)
+			old = old.FieldByName(fieldName)
+			new = new.FieldByName(fieldName)
+		}
+		// if the value has changed, ...
+		if !old.Equal(new) {
+			// ... append it to the list of changed configs
+			changedConfigs = append(changedConfigs, strings.Join(userFacingPath, "."))
+		}
+	}
+
+	if len(changedConfigs) == 0 {
+		return nil
+	}
+
+	message := utils.ResolvePlaceholderString(
+		gui.c.Tr.NonReloadableConfigWarning,
+		map[string]string{
+			"configs": strings.Join(changedConfigs, "\n"),
+		},
+	)
+	gui.c.Confirm(types.ConfirmOpts{
+		Title:  gui.c.Tr.NonReloadableConfigWarningTitle,
+		Prompt: message,
+	})
+
+	return nil
+}
+
+// resetState reuses the repo state from our repo state map, if the repo was
+// open before; otherwise it creates a new one.
 func (gui *Gui) resetState(startArgs appTypes.StartArgs) types.Context {
 	worktreePath := gui.git.RepoPaths.WorktreePath()
 
@@ -367,7 +531,7 @@ func (gui *Gui) resetState(startArgs appTypes.StartArgs) types.Context {
 		gui.State.CurrentPopupOpts = nil
 		gui.Mutexes.PopupMutex.Unlock()
 
-		return gui.c.CurrentContext()
+		return gui.c.Context().Current()
 	}
 
 	contextTree := gui.contextTree()
@@ -386,6 +550,7 @@ func (gui *Gui) resetState(startArgs appTypes.StartArgs) types.Context {
 			BisectInfo:            git_commands.NewNullBisectInfo(),
 			FilesTrie:             patricia.NewTrie(),
 			Authors:               map[string]*models.Author{},
+			MainBranches:          git_commands.NewMainBranches(gui.c.Common, gui.os.Cmd),
 		},
 		Modes: &types.Modes{
 			Filtering:        filtering.New(startArgs.FilterPath, ""),
@@ -484,10 +649,10 @@ func NewGui(
 		RepoStateMap:         map[Repo]*GuiRepoState{},
 		GuiLog:               []string{},
 
-		// originally we could only hide the command log permanently via the config
-		// but now we do it via state. So we need to still support the config for the
-		// sake of backwards compatibility. We're making use of short circuiting here
-		ShowExtrasWindow: cmn.UserConfig.Gui.ShowCommandLog && !config.GetAppState().HideCommandLog,
+		// initializing this to true for the time being; it will be reset to the
+		// real value after loading the user config:
+		ShowExtrasWindow: true,
+
 		Mutexes: types.Mutexes{
 			RefreshingFilesMutex:    &deadlock.Mutex{},
 			RefreshingBranchesMutex: &deadlock.Mutex{},
@@ -508,11 +673,11 @@ func NewGui(
 
 	gui.PopupHandler = popup.NewPopupHandler(
 		cmn,
-		func(ctx goContext.Context, opts types.CreatePopupPanelOpts) error {
-			return gui.helpers.Confirmation.CreatePopupPanel(ctx, opts)
+		func(ctx goContext.Context, opts types.CreatePopupPanelOpts) {
+			gui.helpers.Confirmation.CreatePopupPanel(ctx, opts)
 		},
 		func() error { return gui.c.Refresh(types.RefreshOptions{Mode: types.ASYNC}) },
-		func() error { return gui.State.ContextMgr.Pop() },
+		func() { gui.State.ContextMgr.Pop() },
 		func() types.Context { return gui.State.ContextMgr.Current() },
 		gui.createMenu,
 		func(message string, f func(gocui.Task) error) { gui.helpers.AppStatus.WithWaitingStatus(message, f) },
@@ -544,14 +709,6 @@ func NewGui(
 	// TODO: reset these controllers upon changing repos due to state changing
 	gui.c = helperCommon
 
-	authors.SetCustomAuthors(gui.UserConfig.Gui.AuthorColors)
-	if gui.UserConfig.Gui.NerdFontsVersion != "" {
-		icons.SetNerdFontsVersion(gui.UserConfig.Gui.NerdFontsVersion)
-	} else if gui.UserConfig.Gui.ShowIcons {
-		icons.SetNerdFontsVersion("2")
-	}
-	presentation.SetCustomBranches(gui.UserConfig.Gui.BranchColors)
-
 	gui.BackgroundRoutineMgr = &BackgroundRoutineMgr{gui: gui}
 	gui.stateAccessor = &StateAccessor{gui: gui}
 
@@ -664,27 +821,9 @@ func (gui *Gui) Run(startArgs appTypes.StartArgs) error {
 	// breakpoints and stepping through code can easily take more than 30s.
 	deadlock.Opts.Disable = !gui.Debug || os.Getenv(components.WAIT_FOR_DEBUGGER_ENV_VAR) != ""
 
-	if err := gui.Config.ReloadUserConfig(); err != nil {
-		return nil
-	}
-	userConfig := gui.UserConfig
-
 	gui.g.OnSearchEscape = func() error { gui.helpers.Search.Cancel(); return nil }
-	gui.g.SearchEscapeKey = keybindings.GetKey(userConfig.Keybinding.Universal.Return)
-	gui.g.NextSearchMatchKey = keybindings.GetKey(userConfig.Keybinding.Universal.NextMatch)
-	gui.g.PrevSearchMatchKey = keybindings.GetKey(userConfig.Keybinding.Universal.PrevMatch)
 
-	gui.g.ShowListFooter = userConfig.Gui.ShowListFooter
-
-	if userConfig.Gui.MouseEvents {
-		gui.g.Mouse = true
-	}
-
-	if err := gui.setColorScheme(); err != nil {
-		return err
-	}
-
-	gui.g.SetManager(gocui.ManagerFunc(gui.layout), gocui.ManagerFunc(gui.getFocusLayout()))
+	gui.g.SetManager(gocui.ManagerFunc(gui.layout))
 
 	if err := gui.createAllViews(); err != nil {
 		return err
@@ -741,7 +880,7 @@ func (gui *Gui) RunAndHandleError(startArgs appTypes.StartArgs) error {
 }
 
 func (gui *Gui) checkForDeprecatedEditConfigs() {
-	osConfig := &gui.UserConfig.OS
+	osConfig := &gui.UserConfig().OS
 	deprecatedConfigs := []struct {
 		config  string
 		oldName string
@@ -831,7 +970,7 @@ func (gui *Gui) runSubprocess(cmdObj oscommands.ICmdObj) error { //nolint:unpara
 
 		// scan to buffer to prevent run unintentional operations when TUI resumes.
 		var buffer string
-		fmt.Scanln(&buffer) // wait for enter press
+		_, _ = fmt.Scanln(&buffer) // wait for enter press
 	}
 
 	return err
@@ -864,12 +1003,14 @@ func (gui *Gui) showIntroPopupMessage() {
 			return err
 		}
 
-		return gui.c.Confirm(types.ConfirmOpts{
+		gui.c.Confirm(types.ConfirmOpts{
 			Title:         "",
 			Prompt:        gui.c.Tr.IntroPopupMessage,
 			HandleConfirm: onConfirm,
 			HandleClose:   onConfirm,
 		})
+
+		return nil
 	})
 }
 
@@ -929,27 +1070,26 @@ func (gui *Gui) showBreakingChangesMessage() {
 				return nil
 			}
 
-			return gui.c.Confirm(types.ConfirmOpts{
+			gui.c.Confirm(types.ConfirmOpts{
 				Title:         gui.Tr.BreakingChangesTitle,
 				Prompt:        gui.Tr.BreakingChangesMessage + "\n\n" + message,
 				HandleConfirm: onConfirm,
 				HandleClose:   onConfirm,
 			})
+			return nil
 		})
 	}
 }
 
 // setColorScheme sets the color scheme for the app based on the user config
-func (gui *Gui) setColorScheme() error {
-	userConfig := gui.UserConfig
+func (gui *Gui) setColorScheme() {
+	userConfig := gui.UserConfig()
 	theme.UpdateTheme(userConfig.Gui.Theme)
 
 	gui.g.FgColor = theme.InactiveBorderColor
 	gui.g.SelFgColor = theme.ActiveBorderColor
 	gui.g.FrameColor = theme.InactiveBorderColor
 	gui.g.SelFrameColor = theme.ActiveBorderColor
-
-	return nil
 }
 
 func (gui *Gui) onUIThread(f func() error) {
@@ -965,3 +1105,12 @@ func (gui *Gui) onWorker(f func(gocui.Task) error) {
 func (gui *Gui) getWindowDimensions(informationStr string, appStatus string) map[string]boxlayout.Dimensions {
 	return gui.helpers.WindowArrangement.GetWindowDimensions(informationStr, appStatus)
 }
+
+func (gui *Gui) afterLayout(f func() error) {
+	select {
+	case gui.afterLayoutFuncs <- f:
+	default:
+		// hopefully this never happens
+		gui.c.Log.Error("afterLayoutFuncs channel is full, skipping function")
+	}
+}
