@@ -15,8 +15,8 @@ import (
 	"github.com/samber/lo"
 )
 
-func (gui *Gui) desiredPtySize() *pty.Winsize {
-	width, height := gui.Views.Main.Size()
+func (gui *Gui) desiredPtySize(view *gocui.View) *pty.Winsize {
+	width, height := view.Size()
 
 	return &pty.Winsize{Cols: uint16(width), Rows: uint16(height)}
 }
@@ -25,11 +25,12 @@ func (gui *Gui) onResize() error {
 	gui.Mutexes.PtyMutex.Lock()
 	defer gui.Mutexes.PtyMutex.Unlock()
 
-	for _, ptmx := range gui.viewPtmxMap {
+	for viewName, ptmx := range gui.viewPtmxMap {
 		// TODO: handle resizing properly: we need to actually clear the main view
 		// and re-read the output from our pty. Or we could just re-run the original
 		// command from scratch
-		if err := pty.Setsize(ptmx, gui.desiredPtySize()); err != nil {
+		view, _ := gui.g.View(viewName)
+		if err := pty.Setsize(ptmx, gui.desiredPtySize(view)); err != nil {
 			return utils.WrapError(err)
 		}
 	}
@@ -44,7 +45,7 @@ func (gui *Gui) onResize() error {
 // pseudo-terminal meaning we'll get the behaviour we want from the underlying
 // command.
 func (gui *Gui) newPtyTask(view *gocui.View, cmd *exec.Cmd, prefix string) error {
-	width, _ := gui.Views.Main.Size()
+	width, _ := view.Size()
 	pager := gui.git.Config.GetPager(width)
 	externalDiffCommand := gui.Config.GetUserConfig().Git.Paging.ExternalDiffCommand
 
@@ -69,7 +70,7 @@ func (gui *Gui) newPtyTask(view *gocui.View, cmd *exec.Cmd, prefix string) error
 	var ptmx *os.File
 	start := func() (*exec.Cmd, io.Reader) {
 		var err error
-		ptmx, err = pty.StartWithSize(cmd, gui.desiredPtySize())
+		ptmx, err = pty.StartWithSize(cmd, gui.desiredPtySize(view))
 		if err != nil {
 			gui.c.Log.Error(err)
 		}
