@@ -11,8 +11,8 @@ var NukeWorkingTree = NewIntegrationTest(NewIntegrationTestArgs{
 	Skip:         false,
 	IsDemo:       true,
 	SetupConfig: func(config *config.AppConfig) {
-		config.UserConfig.Gui.NerdFontsVersion = "3"
-		config.UserConfig.Gui.AnimateExplosion = true
+		setDefaultDemoConfig(config)
+		config.GetUserConfig().Gui.AnimateExplosion = true
 	},
 	SetupRepo: func(shell *Shell) {
 		shell.EmptyCommit("blah")
